@@ -461,6 +461,51 @@ class ArgparseBuilder:
             advanced=True,
             caption="Стратегия обработки номеров вопросов",
         )
+        self.add_argument(
+            cmdparse,
+            "--typography_quotes",
+            default="on",
+            choices=["on", "off"],
+            help="typography: try to fix quotes.",
+            advanced=True,
+            caption="Типография: кавычки",
+        )
+        self.add_argument(
+            cmdparse,
+            "--typography_dashes",
+            default="on",
+            choices=["on", "off"],
+            help="typography: try to fix dashes.",
+            advanced=True,
+            caption="Типография: тире",
+        )
+        self.add_argument(
+            cmdparse,
+            "--typography_whitespace",
+            default="on",
+            choices=["on", "off"],
+            help="typography: try to fix whitespace.",
+            advanced=True,
+            caption="Типография: whitespace",
+        )
+        self.add_argument(
+            cmdparse,
+            "--typography_accents",
+            default="on",
+            choices=["on", "off"],
+            help="typography: try to fix accents.",
+            advanced=True,
+            caption="Типография: ударения",
+        )
+        self.add_argument(
+            cmdparse,
+            "--typography_percent",
+            default="on",
+            choices=["on", "off"],
+            help="typography: try to fix percent encoding.",
+            advanced=True,
+            caption="Типография: %-энкодинг ссылок",
+        )
 
         cmdcompose = subparsers.add_parser("compose")
         self.add_argument(
@@ -825,6 +870,15 @@ class ArgparseBuilder:
             help="This flag replaces double line breaks with single ones.",
             caption="Убрать двойные переносы строк",
         )
+        self.add_argument(
+            cmdtrello_download,
+            "--fix_trello_new_editor",
+            "-ftne",
+            action="store_true",
+            help="This flag fixes mess caused by Trello's new editor "
+                "(introduced in early 2023).",
+            caption="Пофиксить новый редактор Трелло",
+        )
         self.add_argument(
             cmdtrello_download,
             "--onlyanswers",
